@@ -4,8 +4,6 @@
 #' properly-formatted JSON string.
 #'
 #' @param script_path The path to the script
-#' @param secret The string to be appended to the name `check_results_` as the list name to collect
-#' results (optional)
 #' @param ignore_errors Whether to ignore errors thrown while executing the script
 #' @param test_dir A directory of tests to glob from
 #'
@@ -16,11 +14,7 @@
 #' \dontrun{
 #' run_autograder("hw01.R", "ABC123", TRUE, "tests")
 #' }
-run_autograder <- function(script_path, secret, ignore_errors, test_dir) {
-  if (missing(secret)) {
-    secret <- make_secret()
-  }
-
+run_autograder <- function(script_path, ignore_errors, test_dir) {
   if (missing(ignore_errors)) {
     ignore_errors <- TRUE
   }
@@ -29,6 +23,6 @@ run_autograder <- function(script_path, secret, ignore_errors, test_dir) {
     test_dir <- "/autograder/source/tests"
   }
 
-  grading_results <- grade_script(script_path, paste0(test_dir, "/*.[Rr]"), secret, ignore_errors)
+  grading_results <- grade_script(script_path, paste0(test_dir, "/*.[Rr]"), ignore_errors)
   return(grading_results$to_json())
 }
