@@ -13,5 +13,5 @@ test_that("grades an R script and returns a JSON object of results", {
   expect_equal(ret, grading_results$to_json())
 
   expect_equal(length(mock_grade_script), 1)
-  expect_args(mock_grade_script, 1, "hw01.R", "/autograder/source/tests/*.[Rr]", "WLayjJ", TRUE)
+  expect_args(mock_grade_script, 1, "hw01.R", "/autograder/source/tests/*.[Rr]", TRUE)
 })
